Index: uspace/lib/libc/generic/fibril.c
===================================================================
--- uspace/lib/libc/generic/fibril.c	(revision 3562ec82ba3dfb266b9ba41dd6db1a9080e1d9b6)
+++ uspace/lib/libc/generic/fibril.c	(revision 87d3ecf9a85a8ae0fc4acfbcaf8178c2f6f0b765)
@@ -65,6 +65,6 @@
 /** Number of threads that are executing a manager fibril and are serialized. */
 static int serialized_threads;	/* Protected by async_futex */
-/** Thread-local count of serialization. If > 0, we must not preempt */
-static __thread int serialization_count;
+/** Fibril-local count of serialization. If > 0, we must not preempt */
+static fibril_local int serialization_count;
 
 /** Setup fibril information into TCB structure */
